import ProductService from '../services/product.js';
import translate from '../utils/translate.js';
import responseCodes from '../response/responseCodes.js';
import notify from '../utils/notify.js';
const TAG = "/controllers/product.js"

class AbstractProductController {
    async create(req, res) {
        const { groupId, localId, abstract_product_id, amount, date_of_production, expiry_date } = req.body;

        await ProductService.create(groupId, localId, abstract_product_id, amount, date_of_production, expiry_date);

        let data = await ProductService.getByLocalId(groupId, localId)

        notify(req.headers.authorization.split(' ')[1], groupId, 'create', 'product', data);

        return res.status(200).send(translate(req.headers["accept-language"], responseCodes.responses.general.ok));
    }

    async update(req, res) {
        let { groupId, localId, abstract_product_id, amount, date_of_production, expiry_date } = req.body;

        if (abstract_product_id) await ProductService.updateAbstractProductId(groupId, localId, abstract_product_id);

        if (amount) await ProductService.updateAmount(groupId, localId, amount);

        if (date_of_production) await ProductService.updateDateOfProduction(groupId, localId, date_of_production);

        if (expiry_date) await ProductService.updateExpiryDate(groupId, localId, expiry_date);

        let data = await ProductService.getByLocalId(groupId, localId)

        notify(req.headers.authorization.split(' ')[1], groupId, 'update', 'product', data);

        return res.status(200).send(translate(req.headers["accept-language"], responseCodes.responses.general.ok));
    }

    async getByLocalId(req, res) {
        let { groupId, localId } = req.params;

        let result = await ProductService.getByLocalId(groupId, localId)

        return res.status(200).send(result)
    }

    async delete(req, res) {
        let { groupId, localId } = req.params;

        let id = (await ProductService.getByLocalId(groupId, localId)).id

        await ProductService.delete(id)

        notify(req.headers.authorization.split(' ')[1], groupId, 'delete', 'product', { local_id: localId });

        return res.status(200).send(translate(req.headers["accept-language"], responseCodes.responses.general.ok));
    }
};

export default new AbstractProductController();